@@ -200,29 +200,34 @@ class WlkataMirobot(AbstractContextManager):
 		'''获取Mirobot的状态信息, 回传的是状态字符'''
 		instruction = '?'
 		ret = self.send_msg(instruction, disable_debug=disable_debug, wait_ok=False, wait_idle=False)
-		recv_str = self.device.serial_device.readline(timeout=0.10) # .decode('utf-8')
+		time.sleep(0.1)
+		recv_str = self.device.serial_device.read(timeout=0.10)
 		self.logger.debug(f"[RECV] {recv_str}")
 		return recv_str
 
 	def get_status(self, disable_debug=False):
 		'''获取并更新Mirobot的状态'''
 		# 因为存在信息丢包的可能,因此需要多查询几次
-		while True:
-			status = None
+		status = None
+		while True:	
 			msg_seg = self.send_cmd_get_status(disable_debug=disable_debug)
 			if "<" in msg_seg and ">" in msg_seg:
 				status_msg = msg_seg
 				try:
+					print("开始解析状态字符串")
 					ret, status = self._parse_status(status_msg)
+					print(f"状态解析: {ret}")
 					if ret:
 						break
 				except Exception as e:
 					print(e)
-			if status is not None:
-				break
+			else:
+				print(f"status code is not legal: {msg_seg}")
 			# 等待一会儿
 			time.sleep(0.1)
+
 		self._set_status(status)
+		return status
 
 	def _set_status(self, status):
 		'''设置新的状态'''
@@ -253,13 +258,15 @@ class WlkataMirobot(AbstractContextManager):
 											  int(pump_pwm),
 											  int(valve_pwm),
 											  bool(motion_mode))
+				self.logger.info(f"state: {state} angle: {return_angles} cartesians: {return_cartesians}")
+				self.logger.info(f"pump_pwm: {pump_pwm}, valve_pwm: {valve_pwm}, motion_mode:{motion_mode}")
 				return True, return_status
 			except Exception as exception:
 				self.logger.exception(MirobotStatusError(f"Could not parse status message \"{msg}\" \n{str(exception)}"),
 									   exc_info=exception)
 		else:
 			self.logger.error(MirobotStatusError(f"Could not parse status message \"{msg}\""))
-			
+		
 		return False, None
 
 	def home(self, has_slider=False):
